@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -1283,6 +1283,44 @@ class ClientTest extends PredisTestCase
         $this->assertSame(Client::VERSION, $libVer);
     }
 
+    /**
+     * @group connected
+     */
+    public function testClientsCreateDifferentPersistentConnections(): void
+    {
+        $client1 = new Client($this->getParameters(['database' => 14, 'persistent' => true]));
+        $client2 = new Client($this->getParameters(['database' => 15, 'persistent' => true]));
+
+        $client1->set('foo', 'bar');
+        $client2->set('foo', 'baz');
+
+        $this->assertSame('bar', $client1->get('foo'));
+        $this->assertSame('baz', $client2->get('foo'));
+    }
+
+    /**
+     * @group connected
+     * @group cluster
+     * @requiresRedisVersion >= 2.0.0
+     */
+    public function testClusterClientsCreateDifferentPersistentConnections(): void
+    {
+        $client1 = new Client(
+            $this->getDefaultParametersArray(),
+            ['cluster' => 'redis', 'parameters' => ['persistent' => true]]
+        );
+        $client2 = new Client(
+            $this->getDefaultParametersArray(),
+            ['cluster' => 'redis', 'parameters' => ['persistent' => true]]
+        );
+
+        $client1->set('{shard1}foo', 'bar');
+        $client2->set('{shard2}foo', 'baz');
+
+        $this->assertSame('bar', $client1->get('{shard1}foo'));
+        $this->assertSame('baz', $client2->get('{shard2}foo'));
+    }
+
     // ******************************************************************** //
     // ---- HELPER METHODS ------------------------------------------------ //
     // ******************************************************************** //
