@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -64,6 +64,7 @@ class FTEXPLAIN_Test extends PredisCommandTestCase
      * @group relay-resp3
      * @return void
      * @requiresRediSearchVersion >= 1.0.0
+     * @requiresRedisVersion <= 7.9.0
      */
     public function testExplainReturnsExecutionPlanForGivenQuery(): void
     {
@@ -119,7 +120,6 @@ EOT;
         $redis = $this->getClient();
 
         $this->expectException(ServerException::class);
-        $this->expectExceptionMessage('index: no such index');
 
         $redis->ftexplain('index', 'query');
     }
