@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -18,6 +18,7 @@ use Predis\Command\Argument\Search\SchemaFields\GeoShapeField;
 use Predis\Command\Argument\Search\SchemaFields\NumericField;
 use Predis\Command\Argument\Search\SchemaFields\TagField;
 use Predis\Command\Argument\Search\SchemaFields\TextField;
+use Predis\Command\Argument\Search\SchemaFields\VectorField;
 use Predis\Command\Argument\Search\SearchArguments;
 use Predis\Command\Redis\PredisCommandTestCase;
 use Predis\Response\ServerException;
@@ -227,6 +228,12 @@ class FTSEARCH_Test extends PredisCommandTestCase
         $redis->ftsearch('idx', '@text_not_empty:("")', $searchArgs);
     }
 
+    /**
+     * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRediSearchVersion >= 2.09.00
+     */
     public function testSearchWithEnhancedMatchingCapabilities(): void
     {
         $redis = $this->getClient();
@@ -403,6 +410,80 @@ class FTSEARCH_Test extends PredisCommandTestCase
         );
     }
 
+    /**
+     * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRedisVersion >= 7.9.0
+     */
+    public function testVectorSearchWithInt8Types(): void
+    {
+        $redis = $this->getClient();
+
+        $this->assertEquals('OK', $redis->ftcreate('test', [
+            new VectorField(
+                'v', 'HNSW',
+                ['TYPE', 'INT8', 'DIM', 2, 'DISTANCE_METRIC', 'L2']
+            ),
+        ]));
+
+        $this->sleep(0.1);
+
+        $a = [1.5, 10];
+        $b = [123, 100];
+        $c = [1, 1];
+
+        $redis->hset('a', 'v', pack('c*', ...$a));
+        $redis->hset('b', 'v', pack('c*', ...$b));
+        $redis->hset('c', 'v', pack('c*', ...$c));
+
+        $searchArguments = new SearchArguments();
+        $searchArguments->params(['vec', pack('c*', ...$a)]);
+        $searchArguments->dialect(2);
+
+        $this->assertEquals(
+            2,
+            $redis->ftsearch('test', '*=>[KNN 2 @v $vec]', $searchArguments)[0]
+        );
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRedisVersion >= 7.9.0
+     */
+    public function testVectorSearchWithUInt8Types(): void
+    {
+        $redis = $this->getClient();
+
+        $this->assertEquals('OK', $redis->ftcreate('test', [
+            new VectorField(
+                'v', 'HNSW',
+                ['TYPE', 'UINT8', 'DIM', 2, 'DISTANCE_METRIC', 'L2']
+            ),
+        ]));
+
+        $this->sleep(0.1);
+
+        $a = [1.5, 10];
+        $b = [123, 100];
+        $c = [1, 1];
+
+        $redis->hset('a', 'v', pack('C*', ...$a));
+        $redis->hset('b', 'v', pack('C*', ...$b));
+        $redis->hset('c', 'v', pack('C*', ...$c));
+
+        $searchArguments = new SearchArguments();
+        $searchArguments->params(['vec', pack('C*', ...$a)]);
+        $searchArguments->dialect(2);
+
+        $this->assertEquals(
+            2,
+            $redis->ftsearch('test', '*=>[KNN 2 @v $vec]', $searchArguments)[0]
+        );
+    }
+
     public function argumentsProvider(): array
     {
         return [
